/* eslint-disable no-unused-vars */
'use strict';

module.exports = app => {
  const { STRING, INTEGER, ENUM, DATE, TEXT } = app.Sequelize;

  const Tag = app.model.define(
    'tag',
    {
      id: { type: INTEGER, primaryKey: true, autoIncrement: true },
      project_id: {
        type: INTEGER,
        allowNull: true,
        comment: '所属项目',
        unique: true,
      },
      mission_id: {
        type: INTEGER,
        allowNull: true,
        comment: '所属任务',
        unique: true,
      },
      tag_name: {
        type: STRING(255),
        allowNull: true,
        comment: '标签名称',
        unique: true,
      },
      other: {
        type: STRING(255),
        allowNull: true,
        comment: '冗余字段',
        unique: true,
      },
      color: {
        type: STRING(255),
        allowNull: true,
        comment: '颜色',
        unique: true,
      },
      created_at: DATE,
      updated_at: DATE,
    },
    {
      timestamps: true,
      createdAt: 'created_at',
      updatedAt: 'updated_at',
    }
  );
  return Tag;
};

//     freezeTableName: true,  使用自定义表名
//     // 实例对应的表名
//     tableName: 'user',
//     // 如果需要sequelize帮你维护createdAt,updatedAt和deletedAt必须先启用timestamps功能
//     // 将createdAt对应到数据库的created_at字段
//     createdAt: 'created_at',
//     // 将updatedAt对应到数据库的updated_at字段
//     updatedAt: 'updated_at',
//     //And deletedAt to be called destroyTime (remember to enable paranoid for this to work)
//     deletedAt: false, //'deleted_at',
//     //删除数据时不删除数据，而是更新deleteAt字段 如果需要设置为true，则上面的deleteAt字段不能为false，也就是说必须启用
//     paranoid: false
